===================
Common Base Objects
===================

Client
======

.. automodule:: aiocouchdb.client
  :members:

Authentication Providers
========================

.. automodule:: aiocouchdb.authn
  :members:

Feeds
=====

.. automodule:: aiocouchdb.feeds
  :members:

Views
=====

.. automodule:: aiocouchdb.views
  :members:

Errors
======

.. automodule:: aiocouchdb.errors
  :members:

Headers
=======

.. automodule:: aiocouchdb.hdrs
  :members:
